@@ -134,6 +134,10 @@ fn build_v8() {
     };
   }
 
+  if target_triple.starts_with("i686-") {
+    gn_args.push(r#"target_cpu="x86""#.to_string());
+  }
+
   let gn_root = env::var("CARGO_MANIFEST_DIR").unwrap();
 
   let gn_out = maybe_gen(&gn_root, gn_args);
@@ -202,14 +206,24 @@ fn static_lib_url() -> String {
     env::var("RUSTY_V8_MIRROR").unwrap_or_else(|_| default_base.into());
   let version = env::var("CARGO_PKG_VERSION").unwrap();
   let target = env::var("TARGET").unwrap();
+
+  // Note: we always use the release build on windows.
   if cfg!(target_os = "windows") {
-    // Note: we always use the release build on windows.
-    format!("{}/v{}/rusty_v8_release_{}.lib", base, version, target)
-  } else {
-    let profile = env::var("PROFILE").unwrap();
-    assert!(profile == "release" || profile == "debug");
-    format!("{}/v{}/librusty_v8_{}_{}.a", base, version, profile, target)
+    return format!("{}/v{}/rusty_v8_release_{}.lib", base, version, target);
   }
+  // Use v8 in release mode unless $V8_FORCE_DEBUG=true
+  let profile = match env_bool("V8_FORCE_DEBUG") {
+    true => "debug",
+    _ => "release",
+  };
+  format!("{}/v{}/librusty_v8_{}_{}.a", base, version, profile, target)
+}
+
+fn env_bool(key: &str) -> bool {
+  matches!(
+    env::var(key).unwrap_or_default().as_str(),
+    "true" | "1" | "yes"
+  )
 }
 
 fn static_lib_name() -> &'static str {
@@ -312,9 +326,18 @@ fn print_link_flags() {
   }
 }
 
+// Chromium depot_tools contains helpers
+// which delegate to the "relevant" `buildtools`
+// directory when invoked, so they don't count.
+fn not_in_depot_tools(p: PathBuf) -> bool {
+  !p.as_path().to_str().unwrap().contains("depot_tools")
+}
+
 fn need_gn_ninja_download() -> bool {
-  let has_ninja = which("ninja").is_ok() || env::var_os("NINJA").is_some();
-  let has_gn = which("gn").is_ok() || env::var_os("GN").is_some();
+  let has_ninja = which("ninja").map_or(false, not_in_depot_tools)
+    || env::var_os("NINJA").is_some();
+  let has_gn = which("gn").map_or(false, not_in_depot_tools)
+    || env::var_os("GN").is_some();
 
   !has_ninja || !has_gn
 }
